@@ -1,5 +1,5 @@
 package Dist::Zilla::Plugin::GithubMeta;
-$Dist::Zilla::Plugin::GithubMeta::VERSION = '0.44';
+$Dist::Zilla::Plugin::GithubMeta::VERSION = '0.48';
 # ABSTRACT: Automatically include GitHub meta information in META.yml
 
 use strict;
@@ -9,6 +9,7 @@ with 'Dist::Zilla::Role::MetaProvider';
 
 use MooseX::Types::URI qw[Uri];
 use Cwd;
+use Try::Tiny;
 
 use namespace::autoclean;
 
@@ -56,10 +57,13 @@ sub _acquire_repo_info {
 
   {
     my $gitver = `git version`;
-    my ($ver) = $gitver =~ m!git version ([0-9.]+)!;
+    my ($ver) = $gitver =~ m!git version ([0-9.]+(\.msysgit)?[0-9.]+)!;
+    $ver =~ s/\.msysgit//;
     chomp $gitver;
     require version;
-    if ( version->parse( $ver ) < version->parse('1.5.0') ) {
+    my $ver_obj = try { version->parse( $ver ) }
+      catch { die "'$gitver' not parsable as '$ver': $_" };
+    if ( $ver_obj < version->parse('1.5.0') ) {
       warn "$gitver is too low, 1.5.0 or above is required\n";
       return;
     }
@@ -136,6 +140,7 @@ sub metadata {
 
 sub _url_for_remote {
   my ($self, $remote) = @_;
+  local $ENV{LC_ALL}='C';
   local $ENV{LANG}='C';
   my @remote_info = `git remote show -n $remote`;
   for my $line (@remote_info) {
@@ -183,7 +188,7 @@ Dist::Zilla::Plugin::GithubMeta - Automatically include GitHub meta information
 
 =head1 VERSION
 
-version 0.44
+version 0.48
 
 =head1 SYNOPSIS
 
@@ -278,7 +283,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Chris Williams, Tatsuhiko Miyagawa and Ricardo SIGNES.
+This software is copyright (c) 2015 by Chris Williams, Tatsuhiko Miyagawa and Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
